@@ -27,9 +27,9 @@ The usage of the following ae namespace portions get demonstrated by this applic
 
 
 .. hint::
-    The Kivy variant of this demo app is additionally using the following ae namespace portions:
-    :mod:`ae.kivy_auto_width`, :mod:`ae.kivy_dyn_chi`, :mod:`ae.kivy_help`, :mod:`ae.kivy_relief_canvas`,
-    :mod:`ae.kivy_app` and :mod:`ae.kivy_user_prefs`.
+    The Kivy variant of this demo app uses additionally the following ae namespace portions: :mod:`ae.kivy_auto_width`,
+    :mod:`ae.kivy_dyn_chi`, :mod:`ae.kivy_help`, :mod:`ae.kivy_relief_canvas`, :mod:`ae.kivy_app` and
+    :mod:`ae.kivy_user_prefs`.
 
 
 features of the Lisz demo app
@@ -54,19 +54,17 @@ features of the Lisz demo app
 lisz application data model
 ---------------------------
 
-The Lisz demo app is managing a recursive item tree - a list of lists - that can be used
-e.g. as a to-do or shopping list.
+The Lisz demo app is managing a recursive item tree - a list of lists - that can be used e.g. as to-do or shopping list.
 
-To keep this demo app simple, the data managed by the Lisz application is a minimalistic
-tree structure that gets stored as an :ref:`application status`, without the need of any
-database. The root node and with that the whole recursive data structure gets stored in
-the app state variable `root_node`.
+To keep this demo app simple, the data managed by the Lisz application is a minimalistic tree structure that gets stored
+as an :ref:`application status`, without the need of any database. The root node and with that the whole recursive data
+structure gets stored in the app state variable `root_node`.
 
-The root of the tree structure is a list of the type `LiszNode` containing list items of
-type `LiszItem`. A `LiszItem` element represents a dict of the type `Dict[str, Any]`.
+The root of the tree structure is a list of the type `LiszNode` containing list items of type `LiszItem`. A `LiszItem`
+element represents a dict of the type `Dict[str, Any]`.
 
-Each `LiszItem` element of the tree structure is either a leaf or a node. And each node is a
-sub-list with a recursive structure identical to the root node and of the type `LiszNode`.
+Each `LiszItem` element of the tree structure is either a leaf or a node. And each node is a sub-list with a recursive
+structure identical to the root node and of the type `LiszNode`.
 
 The following graph is showing an example data tree:
 
@@ -85,8 +83,7 @@ The following graph is showing an example data tree:
         rec3:CBA -> "Leaf Item CBA"
     }
 
-The above example tree structure is containing the root node items `A` (which is a leaf)
-and `C` (which is a sub-node).
+The above example tree structure is containing the root node items `A` (which is a leaf) and `C` (which is a sub-node).
 
 The node `C` consists of the items `CA` and `CB` where `CA` is a leaf and `CB` is a node.
 
@@ -96,10 +93,8 @@ Finally the first item of the node `CB` is another sub-node with the leaf item `
 GUI framework demo implementations
 ==================================
 
-The plan is to integrate the following GUI frameworks on
-top of the :class:`abstract base class <~ae.gui_app.MainAppBase>`
-(implemented in the :mod:`ae.gui_app` portion of the
-`ae namespace <https://ae.readthedocs.io>`__):
+The plan is to integrate the following GUI frameworks on top of the :class:`abstract base class <~.gui_app.MainAppBase>`
+(implemented in the :mod:`ae.gui_app` portion of the `ae namespace <https://ae.readthedocs.io>`__):
 
 * :mod:`Kivy <ae.kivy_app>` based on the `kivy framework <https://kivy.org>`__:
   `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
@@ -113,11 +108,9 @@ top of the :class:`abstract base class <~ae.gui_app.MainAppBase>`
 * :mod:`pygobject <ae.pygobject_app>`
 * :mod:`AppJar <ae.appjar_app>`
 
-The main app base mixin class :class:`LiszDataMixin` provided by this module
-is used for to manage the common data structures, functions and methods
-for the various demo applications variants based on :mod:`ae.gui_app`
-and the related GUI framework implementation portions
-(like e.g. :mod:`ae.kivy_app` and :mod:`ae.enaml_app`) of the ae namespace.
+The main app base mixin class :class:`LiszDataMixin` provided by this module is used to manage the common data
+structures, functions and methods for the various demo applications variants based on :mod:`ae.gui_app` and the related
+GUI framework implementation portions (like e.g. :mod:`ae.kivy_app` and :mod:`ae.enaml_app`) of the ae namespace.
 
 
 gui framework implementation variants
@@ -126,10 +119,8 @@ gui framework implementation variants
 kivy
 ----
 
-The `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__ is based
-on the `kivy framework <https://kivy.org>`__,
-a `pypi package <https://pypi.org/project/Kivy/>`__
-documented `here <https://kivy.org/doc/stable/>`__.
+The `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `kivy framework <https://kivy.org>`__, a
+`pypi package <https://pypi.org/project/Kivy/>`__ documented `here <https://kivy.org/doc/stable/>`__.
 
 .. list-table::
 
@@ -179,16 +170,15 @@ documented `here <https://kivy.org/doc/stable/>`__.
 kivy wish list
 ^^^^^^^^^^^^^^
 
-* kv language looper pseudo widget (like enaml is providing) for to easily generate sets of similar widgets.
+* kv language looper pseudo widget (like enaml is providing) to easily generate sets of similar widgets.
 
 
 enaml
 -----
 
-The `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is
-based on the `enaml framework <https://pypi.org/project/enaml/>`__,
-a `pypi package <https://pypi.org/project/enaml/>`__
-documented `here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
+The `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is based on the
+`enaml framework <https://pypi.org/project/enaml/>`__, a `pypi package <https://pypi.org/project/enaml/>`__ documented
+`here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
 
 .. list-table::
     :widths: 27 66
@@ -211,8 +201,8 @@ documented `here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
 automatic update of widget attributes
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-Dependencies have to be executed/read_from, so e.g. the icon attribute will not be updated if
-app.app_state_light_theme gets changed::
+Dependencies have to be executed/read_from, so e.g. the icon attribute will not be updated if app.app_state_light_theme
+gets changed::
 
     icon << main_app.cached_icon('font_size') or app.app_state_light_theme
 
@@ -222,16 +212,15 @@ In contrary the icon will be updated by the following two statements::
     icon << app.app_state_light_theme == None or main_app.cached_icon('font_size')
 
 KeyEvent implementation based on this SO answer posted by the enamlx author frmdstryr/Jairus Martin:
-https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-enaml. Alternative
-and more complete implementation can be found in the enamlx package (https://github.com/frmdstryr/enamlx).
+https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-enaml. Alternative and more complete
+implementation can be found in the enamlx package (https://github.com/frmdstryr/enamlx).
 
 
 enaml wish list
 ^^^^^^^^^^^^^^^
 
 * type and syntax checking, code highlighting and debugging of enaml files within PyCharm.
-* fix freezing of linux/Ubuntu system in debugging of opening/opened PopupViews in PyCharm
-  (workaround: killing of java PyCharm process).
+* fix freezing of linux/Ubuntu system in debugging of opening/opened PopupViews in PyCharm.
 """
 import ast
 import os
@@ -247,7 +236,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.1.44'
+__version__ = '0.2.45'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -255,8 +244,8 @@ FLOW_PATH_TEXT_SEP = " / "  #: flow path separator for :meth:`~LiszDataMixin.flo
 
 FOCUS_FLOW_PREFIX = "->"    #: prefix shown in front of flow key of focused item
 
-INVALID_ITEM_ID_PREFIX_CHARS = '[' + '{'  #: invalid initial chars in item id (for to detect id | literal in flow key)
-# currently only the '[' char is used (for to put the node list data as literal in a flow key - see
+INVALID_ITEM_ID_PREFIX_CHARS = '[' + '{'  #: invalid initial chars in item id (to detect id | literal in flow key)
+# currently only the '[' char is used (to put the node list data as literal in a flow key - see
 
 NODE_FILE_PREFIX = 'node_'                      #: file name prefix for node imports/exports
 NODE_FILE_EXT = '.txt'                          #: file extension for node imports/exports
@@ -349,7 +338,7 @@ def flow_path_items_from_text(text: str) -> Tuple[str, str, LiszNode]:
 
 
 def item_sel_filter(item: LiszItem) -> bool:
-    """ callable for to filter selected LiszItems.
+    """ callable to filter selected LiszItems.
 
     :param item:                item data structure to check.
     :return:                    True if item is a selected leaf or if item is a node with only selected sub-leaves,
@@ -364,7 +353,7 @@ def item_sel_filter(item: LiszItem) -> bool:
 
 
 def item_unsel_filter(item: LiszItem) -> bool:
-    """ callable for to filter unselected LiszItems.
+    """ callable to filter unselected LiszItems.
 
     :param item:                item data structure to check.
     :return:                    True if item is an unselected leaf or if item is a node with only unselected leaves,
@@ -380,12 +369,12 @@ def item_unsel_filter(item: LiszItem) -> bool:
 
 class LiszDataMixin:
     """ lisz data model - independent from used GUI framework. """
-    root_node: LiszNode             #: root of lisz data structure
+    root_node: LiszNode = list()    #: root of lisz data structure
     current_node_items: LiszNode    #: node item data of the current node / sub list (stored as app state via root_node)
     filtered_indexes: List[int]     #: indexes of the filtered/displayed items in the current node
     # additional app-common attributes (never directly referenced/needed, KEEP for completeness/documentation).
-    filter_selected: bool           #: True for to hide/filter selected node items
-    filter_unselected: bool         #: True for to hide/filter unselected node items
+    filter_selected: bool = False   #: True to hide/filter selected node items
+    filter_unselected: bool = False  #: True to hide/filter unselected node items
 
     # mixin shadow attributes - implemented by :class:`~ae.console_app.ConsoleApp` or :class:`~ae.gui_app.MainAppBase`
     debug_level: int                #: :attr:`~AppBase.debug_level`
@@ -422,7 +411,7 @@ class LiszDataMixin:
         err_msg = self.edit_validate(-1, item_id, want_node=want_node,
                                      parent_node=node_to_add_to, new_item_index=new_item_index)
         if not err_msg:
-            # overwrite inserted nid because edit_validate(used for to ensure proper id and no dup) creates new nid
+            # overwrite inserted nid because edit_validate(used to ensure proper id and no dup) creates new nid
             node_to_add_to[new_item_index] = nid
 
         elif want_node:
@@ -491,7 +480,7 @@ class LiszDataMixin:
 
         :param item_ids:        tuple of item ids to identify the items/sub-nodes to be deleted.
         :param parent_node:     node from where the item has to be removed from (default=current node).
-        :param node_only:       True if only delete the sub-node of the identified item, False for to delete the item.
+        :param node_only:       True if only delete the sub-node of the identified item, False to delete the item.
         """
         if parent_node is None:
             parent_node = self.current_node_items
@@ -712,7 +701,7 @@ class LiszDataMixin:
         """ generate shortened display text from the passed flow path.
 
         :param flow_path:       flow path list.
-        :param min_len:         minimum length of node ids (flow id keys). Pass zero value for to not shorten ids.
+        :param min_len:         minimum length of node ids (flow id keys). Pass zero value to not shorten ids.
         :param display_root:    pass True to return FLOW_PATH_ROOT_ID on empty/root path.
         :param separator:       path item separator (default=FLOW_PATH_TEXT_SEP).
         :return:                shortened display text string of the passed flow path (which can be converted back
@@ -898,7 +887,7 @@ class LiszDataMixin:
 
         :param node:            node to get info for.
 
-        :param what:            pass tuple of statistic info fields for to include only these into the returned dict
+        :param what:            pass tuple of statistic info fields to include only these into the returned dict
                                 (passing an empty tuple or nothing will include all the following fields):
 
                                 * 'count': number of items (nodes and leaves) in this node (including sub-nodes).
@@ -959,7 +948,7 @@ class LiszDataMixin:
 
         :param _key:            flow key (item id).
         :param event_kwargs:    event kwargs.
-        :return:                True for to process/change flow id.
+        :return:                True to process/change flow id.
         """
         self.play_sound(id_of_flow('enter', 'item'))
         event_kwargs['changed_event_name'] = 'refresh_all'
@@ -970,7 +959,7 @@ class LiszDataMixin:
 
         :param _key:            flow key (item id).
         :param event_kwargs:    event kwargs.
-        :return:                True for to process/change flow id.
+        :return:                True to process/change flow id.
         """
         self.play_sound(id_of_flow('leave', 'item'))
         event_kwargs['changed_event_name'] = 'refresh_all'
@@ -981,7 +970,7 @@ class LiszDataMixin:
 
         :param item_id:         item id of the leaf to toggle selection for.
         :param event_kwargs:    event kwargs.
-        :return:                True for to process/change flow id.
+        :return:                True to process/change flow id.
         """
         self.toggle_item_sel(self.find_item_index(item_id))
         event_kwargs['flow_id'] = id_of_flow('focus', 'item', item_id)
@@ -994,7 +983,7 @@ class LiszDataMixin:
         :param event_kwargs:    event kwargs, containing a `set_sel_to` key with a boolean value, where
                                 True will select and False deselect the item (or the sub-items if the item is a
                                 non-empty node).
-        :return:                True for to process/change flow id.
+        :return:                True to process/change flow id.
 
         This flow change event can be used alternatively to :meth:`~LiszDataMixin.on_item_sel_toggle`
         for more sophisticated Lisz app implementations, like e.g. the
@@ -1015,7 +1004,7 @@ class LiszDataMixin:
         return True
 
     def on_key_press(self, modifiers: str, key_code: str) -> bool:
-        """  check key press event for to be handled and processed as command/action.
+        """  check key press event to be handled and processed as command/action.
 
         :param modifiers:       modifier keys string.
         :param key_code:        key code string.
@@ -1098,7 +1087,7 @@ class LiszDataMixin:
 
                                 `export_path` specifies the destination folder of the export action (default='.'/CWD).
 
-        :return:                True for to process/change flow.
+        :return:                True to process/change flow.
         """
         flow_path = ast.literal_eval(flow_path_text) if flow_path_text and flow_path_text[0] == '[' else \
             self.flow_path_from_text(flow_path_text)
@@ -1143,11 +1132,11 @@ class LiszDataMixin:
     def on_node_jump(self, flow_path_text: str, event_kwargs: Dict[str, Any]) -> bool:
         """ FlowButton clicked event handler restoring flow path from the flow key.
 
-        Used for to jump to node specified by the flow path text in the passed flow_id key.
+        Used to jump to node specified by the flow path text in the passed flow_id key.
 
         :param flow_path_text:  flow path text (identifying where to jump to).
-        :param event_kwargs:    event arguments (used for to reset flow id).
-        :return:                True for to process/change flow.
+        :param event_kwargs:    event arguments (used to reset flow id).
+        :return:                True to process/change flow.
         """
         flow_path = self.flow_path_from_text(flow_path_text)
 
@@ -1203,12 +1192,12 @@ class LiszDataMixin:
 
     def shrink_node_size(self, node: LiszNode, item_filter: Optional[Callable[[LiszItem], bool]] = None,
                          recursive: bool = True):
-        """ shrink node size by removing unneeded items and `sel` keys, e.g. for to export or save space in config file.
+        """ shrink node size by removing unneeded items and `sel` keys, e.g. to export or save space in config file.
 
         :param node:            start or root node to shrink (in-place!).
-        :param item_filter:     pass callable for to remove items from the passed node and its sub-nodes.
+        :param item_filter:     pass callable to remove items from the passed node and its sub-nodes.
                                 The callable is getting passed each item as argument and has to return True
-                                for to remove it from its node.
+                                to remove it from its node.
         :param recursive:       pass False if only the passed start node has to be shrunk.
         """
         del_items = list()
@@ -1232,14 +1221,14 @@ class LiszDataMixin:
                      sub_ids: Optional[List[str]] = None) -> List[str]:
         """ return item names/ids of the specified items including their sub-node items (if exists and recursive==True).
 
-        Used for to determine the affected item ids if user want to delete or de-/select the sub-items of
+        Used to determine the affected item ids if user want to delete or de-/select the sub-items of
         the item(s) specified by the passed arguments.
 
         :param node:            searched node, if not passed use the current node as default.
         :param item_ids:        optional item id filter, if passed only items with an id in this tuple will be returned.
                                 This filter will not be used for sub-node filtering (if recursive==True).
         :param leaves_only:     pass False to also include/return node item ids.
-        :param hide_sel_val:    pass False/True for to exclude un-/selected leaf items from the returned list of ids.
+        :param hide_sel_val:    pass False/True to exclude un-/selected leaf items from the returned list of ids.
                                 If None or not passed then all found items will be included.
         :param recursive:       pass False if only the passed start node has to be investigated/included.
         :param sub_ids:         already found sub item ids (used for the recursive calls of this method).
